@@ -7,15 +7,20 @@ import yaml
 from cli import *
 from pathlib import Path
 from jinja2 import Environment, FileSystemLoader
+from furl import furl
 
 class NxPyDocs():
     def __init__(self,
                 command,
                 filetype,
-                repo):
+                repo,
+                username,
+                token,):
         self.command = command
         self.filetype = filetype
         self.repo = repo
+        self.username = username
+        self.token = token
         self.supported_templates = [
                             # 'show access-lists',
                             # 'show bgp process vrf all',
@@ -53,6 +58,7 @@ class NxPyDocs():
                         self.clone()
                         self.pick_filetype(parsed_json)
                         self.send_to_repo()
+                        self.cleanup()
                     else:
                         self.pick_filetype(parsed_json)
         else:
@@ -64,6 +70,7 @@ class NxPyDocs():
                         self.clone()
                         self.pick_filetype(parsed_json)
                         self.send_to_repo()
+                        self.cleanup()
                     else: 
                         self.pick_filetype(parsed_json)
                 else:
@@ -92,8 +99,7 @@ class NxPyDocs():
     def json_file(self, parsed_json):
         with open(' %s.json' % self.command, 'w') as f:
             f.write(json.dumps(parsed_json,indent=4, sort_keys=True))
-        click.secho(json.dumps(parsed_json,indent=4, sort_keys=True))
-        click.secho("JSON file created at %s / %s.json" % (sys.path[0],self.command),
+        click.secho(json.dumps(parsed_json,indent=4, sort_keys=True),
         fg='green')
 
     def yaml_file(self, parsed_json):
@@ -101,9 +107,7 @@ class NxPyDocs():
         clean_yaml = dirty_yaml.replace("!!python/unicode","")
         with open(' %s.yaml' % self.command, 'w') as f:
             f.write(clean_yaml)
-        click.secho(clean_yaml)
-        click.secho("YAML file created at %s / %s.yaml" % (sys.path[0],self.command),
-        fg='green')
+        click.secho(clean_yaml, fg='green')
 
     def html_file(self, parsed_json):
         template_dir = Path(__file__).resolve().parent
@@ -114,8 +118,6 @@ class NxPyDocs():
         with open('%s.html' % self.command, 'w') as f:
             f.write(html_output)
         click.secho(json.dumps(parsed_json,indent=4, sort_keys=True))
-        click.secho("HTML file created at %s / %s.html" % (sys.path[0],self.command),
-            fg='green')
 
     def markdown_file(self, parsed_json):
         template_dir = Path(__file__).resolve().parent
@@ -125,9 +127,8 @@ class NxPyDocs():
             data_to_template=parsed_json)
         with open('%s.md' % self.command, 'w') as f:
             f.write(markdown_output)
-        click.secho(json.dumps(parsed_json,indent=4, sort_keys=True))
-        click.secho("Markdown file created at %s / %s.md" % (sys.path[0],self.command),
-            fg='green')
+        click.secho(json.dumps(parsed_json,indent=4, sort_keys=True),
+        fg='green')
 
     def csv_file(self, parsed_json):
         template_dir = Path(__file__).resolve().parent
@@ -138,9 +139,8 @@ class NxPyDocs():
             )
         with open('%s.csv' % self.command, 'w') as f:
             f.write(csv_output)
-        click.secho(json.dumps(parsed_json,indent=4, sort_keys=True))
-        click.secho("CSV file created at %s / %s.csv" % (sys.path[0],self.command),
-            fg='green')
+        click.secho(json.dumps(parsed_json,indent=4, sort_keys=True),
+        fg='green')
 
     def mindmap_file(self, parsed_json):
         template_dir = Path(__file__).resolve().parent
@@ -151,9 +151,8 @@ class NxPyDocs():
             )
         with open('%s mindmap.md' % self.command, 'w') as f:
             f.write(mindmap_output)
-        click.secho(json.dumps(parsed_json,indent=4, sort_keys=True))
-        click.secho("Mindmap file created at %s / %s.md" % (sys.path[0],self.command),
-            fg='green')
+        click.secho(json.dumps(parsed_json,indent=4, sort_keys=True),
+        fg='green')
 
     def all_files(self, parsed_json):
         self.json_file(parsed_json)
@@ -170,7 +169,15 @@ class NxPyDocs():
     def send_to_repo(self):
         os.system("git add *")
         os.system("git commit -am 'nxpydocs generated this commit'")
-        os.system("git push")
+        url = furl(self.repo)
+        url.username = self.username
+        url.password = self.token
+        url.tostr()
+        os.system("git push %s" % url)
+
+    def cleanup(self):
+        os.chdir(sys.path[0])
+        os.system("rm -rf nxpydocs")
 
 @click.command()
 @click.option('--command',
@@ -195,13 +202,25 @@ class NxPyDocs():
     prompt='Git Repository',
     help=('The Git repository to send the output files'),
     required=False)
+@click.option('--username',
+    prompt='Git Repository Username',
+    help=('The Git repository username'),
+    required=False)
+@click.option('--token',
+    prompt='Git Repository token',
+    help=('The Git repository token'),
+    required=False)    
 def cli(command,
         filetype,
         repo,
+        username,
+        token
         ):
     invoke_class = NxPyDocs(command,
                             filetype,
-                            repo
+                            repo,
+                            username,
+                            token
                         )
     invoke_class.nxpydocs()
 
